==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/courbesdialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef COURBESDIALOG_H
#define COURBESDIALOG_H

#include "ui_courbesdialog.h"
#include "highlighter.h"
#include "pdfviewer.h"

#include <QProcess>
#include <QPointer>
#include <QCloseEvent>
#include <QProgressDialog>

class CourbesDialog : public QDialog  {
   Q_OBJECT
public:
	CourbesDialog(QWidget *parent=0);
	~CourbesDialog();
	Ui::CourbesDialog ui;
QString pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
QColor couleurSupp1,couleurSupp2,couleurSupp3;

private :
QStringList expressionList, varminList, varmaxList, couleurList, styleList;
QString asyMessage;
QStringList itemMacros, codeMacros;
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QPointer<QProcess> asy_pdf_proc;
bool estModifie, existvaleur, erreurProcessus;
Highlighter *highlighterSupp;
QPointer<PdfViewer> pdfviewerWindow;
QPointer<QProgressDialog> progressDialog;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActiverFonctions(bool etat);
void ActiverAxes(bool etat);
void ActiverGrille(bool etat);
bool Operateur(QString mot);
bool Fonction(QString mot);
int Priorite(QString mot);
QString CalculOp(QString n,QString m,QString x,QString variable);
QString CalculAp(QString n,QString x,QString variable);
QString CalculerExpression(QString expression, QString variable);
QString CalculerExpressionArrondi(QString expression, QString variable);

QString GenererCode();
void AfficherCode();
void ajouterFonction();
void supprimerFonction();
void actualiserExpression();
void actualiserVarmin();
void actualiserVarmax();
void actualiserCouleur();
void actualiserStyle();
void actualiserItemInfo();
int numeroItem();
void NouvelleCourbe();
void SauverCourbe();
void ChargerCourbe();

void AsyPdfTemp();
void finAsyPdfProcess(int err);
void VoirTemp();
void readInfoOutput();

void NettoyerCode();
void NettoyerSupp();
void AjouterMacro(int item);

void Aide();


void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void asy_pdf_fini();
};
#endif

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/courbesdialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#ifndef COURBESDIALOG_H
#define COURBESDIALOG_H

#include "ui_courbesdialog.h"
#include "highlighter.h"
#include "pdfviewer.h"
#include "cmdlauncher.h"


#include <QPointer>
#include <QCloseEvent>


class CourbesDialog : public QDialog  {
   Q_OBJECT
public:
	CourbesDialog(QWidget *parent=0);
	~CourbesDialog();
	Ui::CourbesDialog ui;
QString extraPath, pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
QColor couleurSupp1,couleurSupp2,couleurSupp3;

private :
QStringList expressionList, varminList, varmaxList, couleurList, styleList;
QStringList itemMacros, codeMacros;
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QPointer<CmdLauncher> asy_pdf_proc;
bool estModifie, existvaleur, erreurProcessus;
Highlighter *highlighterSupp;
QPointer<PdfViewer> pdfviewerWindow;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActiverFonctions(bool etat);
void ActiverAxes(bool etat);
void ActiverGrille(bool etat);
bool Operateur(QString mot);
bool Fonction(QString mot);
int Priorite(QString mot);
QString CalculOp(QString n,QString m,QString x,QString variable);
QString CalculAp(QString n,QString x,QString variable);
QString CalculerExpression(QString expression, QString variable);
QString CalculerExpressionArrondi(QString expression, QString variable);

QString GenererCode();
void AfficherCode();
void ajouterFonction();
void supprimerFonction();
void actualiserExpression();
void actualiserVarmin();
void actualiserVarmax();
void actualiserCouleur();
void actualiserStyle();
void actualiserItemInfo();
int numeroItem();
void NouvelleCourbe();
void SauverCourbe();
void ChargerCourbe();

void AsyPdfTemp();
void VoirTemp();
void ErreurCompilation();

void NettoyerCode();
void NettoyerSupp();
void AjouterMacro(int item);

void Aide();


void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void asy_pdf_fini();
};
#endif
